mafw.db.std\_tables
===================

.. automodule:: mafw.db.std_tables

   
   .. rubric:: Module Attributes

   .. autosummary::
   
      standard_tables
   
   .. rubric:: Classes

   .. autosummary::
   
      OrphanFile
      PlotterOutput
      StandardTable
      TriggerStatus
   
   .. rubric:: Exceptions

   .. autosummary::
   
      OrphanFileDoesNotExist
      PlotterOutputDoesNotExist
      StandardTableDoesNotExist
      TriggerStatusDoesNotExist
   